@@ -50,7 +50,7 @@ logger = logging.getLogger("griffon")
 default_conditions: dict = {}
 
 
-@click.group(name="CORGI")
+@click.group(name="component-registry")
 @click.pass_context
 def corgi_grp(ctx):
     pass
